package net.carbon.enums;

import lombok.Getter;

/**
 * @Description 状态码定义约束，共6位数，前三位代表服务，后4位代表接口
 * 比如 商品服务210,购物车是220、用户服务230，403代表权限
 **/
public enum BizCodeEnum {


    /**
     * 通用操作码
     */
    OPS_REPEAT(110001, "重复操作"),

    /**
     * 验证码
     */
    CODE_TO_ERROR(240001, "接收号码不合规"),

    CODE_LIMITED(240002, "验证码发送过快"),

    CODE_ERROR(240003, "验证码错误"),

    CODE_CAPTCHA(240101, "图形验证码错误"),

    /**
     * 账号
     */
    ACCOUNT_REPEAT(250001, "账号已经存在"),

    ACCOUNT_UNREGISTER(250002, "账号不存在"),

    ACCOUNT_PWD_ERROR(250003, "账号或者密码错误"),

    ACCOUNT_UNLOGIN(250004, "账号未登录"),

    ILLEGAL_ARGUMENT(250005, "参数非法"),


    /**
     * 流控操作
     */

    CONTROL_FLOW(500101, "限流控制"),

    CONTROL_DEGRADE(500201, "降级控制"),

    CONTROL_AUTH(500301, "认证控制");

    @Getter
    private int code;

    @Getter
    private String message;

    private BizCodeEnum(int code, String message) {
        this.code = code;
        this.message = message;
    }
}