package net.carbon.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import net.carbon.bean.PageResponse;
import net.carbon.mapper.EconomicsMapper;
import net.carbon.model.po.EconomicsDO;
import net.carbon.model.po.LabelDO;
import net.carbon.model.request.EconomicsUpdateRequest;
import net.carbon.model.vo.EconomicsVO;
import net.carbon.model.vo.LabelVO;
import net.carbon.service.EconomicsService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

/**
 * (Economics)表服务实现类
 *
 * @author jieyuu
 * @since 2025-02-21 13:37:20
 */
@Service
public class EconomicsServiceImpl extends ServiceImpl<EconomicsMapper, EconomicsDO> implements EconomicsService {

    @Autowired
    private EconomicsMapper economicsMapper;

    @Override
    public PageResponse<EconomicsVO> getPage(Long pageSize, Long current) {

        Page<EconomicsDO> pageInfo = new Page<>(current, pageSize);
        IPage<EconomicsDO> economicsDOPage = economicsMapper.selectPage(pageInfo, new LambdaQueryWrapper<EconomicsDO>());

        PageResponse<EconomicsVO> pageResponse = new PageResponse<>();

        List<EconomicsVO> economicsVOS = economicsDOPage.getRecords().stream().map(obj -> {
            EconomicsVO economicsVO = new EconomicsVO();
            BeanUtils.copyProperties(obj, economicsVO);
            return economicsVO;
        }).collect(Collectors.toList());

        pageResponse.setPageSize(economicsDOPage.getSize());
        pageResponse.setCurrent(economicsDOPage.getCurrent());
        pageResponse.setTotal(economicsDOPage.getTotal());
        pageResponse.setRecords(economicsVOS);
        return pageResponse;
    }

    @Override
    public Integer delete(Long id) {

        int row = economicsMapper.deleteById(id);
        return row;
    }

    @Override
    public Integer updateById(EconomicsUpdateRequest economicsUpdateReq) {
        EconomicsDO economicsDO = new EconomicsDO();
        BeanUtils.copyProperties(economicsUpdateReq, economicsDO);
        // 设置为0
        economicsDO.setIsDelete((byte) 0);
        int row = economicsMapper.updateById(economicsDO);
        return row;
    }
}

