package net.carbon.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import jakarta.annotation.Resource;
import net.carbon.bean.PageResponse;
import net.carbon.mapper.LabelMapper;
import net.carbon.model.po.LabelDO;
import net.carbon.model.request.LabelUpdateRequest;
import net.carbon.model.vo.LabelVO;
import net.carbon.service.LabelService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 碳排放-城市高质量发展指标体系-标签表 服务实现类
 * </p>
 *
 * @author jieyuu
 * @since 2025-02-19
 */
@Service
public class LabelServiceImpl extends ServiceImpl<LabelMapper, LabelDO> implements LabelService {

    @Autowired
    private LabelMapper labelMapper;

    @Override
    public PageResponse<LabelVO> getList(Long pageSize, Long current) {

        Page<LabelDO> pageInfo = new Page<>(current, pageSize);
        IPage<LabelDO> labelDOPage = labelMapper.selectPage(pageInfo, new LambdaQueryWrapper<LabelDO>());

        PageResponse<LabelVO> pageResponse = new PageResponse<>();

        List<LabelVO> labelVOS = labelDOPage.getRecords().stream().map(obj -> {
            LabelVO labelVO = new LabelVO();
            BeanUtils.copyProperties(obj, labelVO);
            return labelVO;
        }).collect(Collectors.toList());

        pageResponse.setPageSize(labelDOPage.getSize());
        pageResponse.setCurrent(labelDOPage.getCurrent());
        pageResponse.setTotal(labelDOPage.getTotal());
        pageResponse.setRecords(labelVOS);
        return pageResponse;
    }

    @Override
    public int delete(Long id) {
        LambdaQueryWrapper<LabelDO> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(LabelDO::getId, id);
        return labelMapper.delete(queryWrapper);
    }

    @Override
    public int updateById(LabelUpdateRequest labelUpdateReq) {
        LabelDO labelDO = new LabelDO();

        BeanUtils.copyProperties(labelUpdateReq, labelDO);
        labelDO.setIsDeleted(0);

        int row = labelMapper.updateById(labelDO);
        return row;
    }
}
